import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleBand, scaleLinear, max } from 'd3';
import { useData } from './useData';
import { BarChartAxisBottom } from './BarChartAxisBottom';
import { BarChartAxisLeft } from './BarChartAxisLeft';
import { Marks } from './Marks';

const width = 960;
const height = 500;
const margin = {
  top: 20,
  right: 30,
  bottom: 40,
  left: 220
};
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

const App = () => {
  const data = useData();

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const xValue = d => d.Population;
  const yValue = d => d.Country;

  const xScale = scaleLinear()
    .domain([0, max(data, xValue)])
    .range([0, innerWidth]);

  const yScale = scaleBand()
    .domain(data.map(yValue))
    .range([0, innerHeight])
  	.paddingInner(0.15);

  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left}, ${margin.top})`}
      >
        <BarChartAxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
        />
        <BarChartAxisLeft yScale={yScale} />
        <Marks 
          data={data} 
          xScale={xScale} 
          yScale={yScale}
          xValue={xValue}
          yValue={yValue} 
        />
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
